@@ -4,8 +4,12 @@ from django import forms
 from django.forms.models import modelformset_factory
 
 from generic_images.models import AttachedImage
-from generic_images.forms import AttachedImageForm
 
+class ImageEditForm(forms.ModelForm):
+    class Meta:
+        model = AttachedImage
+        fields = ['caption']
+            
 
 PhotoFormSet = modelformset_factory(AttachedImage, 
                                     extra=3, 
